@@ -18,6 +18,7 @@ import sys
 import urllib2
 import re
 import time
+import os
 from os import path
 from calculate.lib.configparser import ConfigParserCaseSens, Error as CPError
 from calculate.lib.utils.tools import SingletonParam
@@ -215,6 +216,11 @@ def fetch_packages(url_binhost, cache_fn, timeout=300, ttl=30 * DAYS):
     :param ttl:
     :return:
     """
+    if path.exists(cache_fn):
+        try:
+            os.unlink(cache_fn)
+        except OSError:
+            pass
     data = None
     for uri in ("Packages.xz", "Packages"):
         fn = path.join(url_binhost, uri)
@@ -231,7 +237,7 @@ def fetch_packages(url_binhost, cache_fn, timeout=300, ttl=30 * DAYS):
             data = ""
     if not data:
         raise BinhostError(_("Failed to fetch Packages from binary host %s")
-                           %url_binhost)
+                           % url_binhost)
     pi = PackagesIndex(data)
     pi["TTL"] = str(ttl)
     pi["DOWNLOAD_TIMESTAMP"] = str(int(time.time()))
